pub enum Error<Ctx: Context> {
UnexpectedResume(Resume<Ctx>, &'static str),
}Variants
UnexpectedResume(Resume<Ctx>, &'static str)
The coroutine was resumed with a value which does not match the expected type of resume value.