pub enum HeightStartType {
Start,
Restart,
}Expand description
Indicates whether the height is the start of a new height or a restart of the latest height
Variants
Implementations
Sourceimpl HeightStartType
impl HeightStartType
pub const fn from_is_restart(is_restart: bool) -> Self
pub const fn is_start(&self) -> bool
pub const fn is_restart(&self) -> bool