pub enum Input<Ctx: Context> {
SendStatusUpdate,
Status(Status<Ctx>),
StartedHeight(Ctx::Height, HeightStartType),
Decided(Ctx::Height),
ValueRequest(InboundRequestId, PeerId, ValueRequest<Ctx>),
ValueResponse(OutboundRequestId, PeerId, Option<ValueResponse<Ctx>>),
GotDecidedValues(InboundRequestId, RangeInclusive<Ctx::Height>, Vec<RawDecidedValue<Ctx>>),
SyncRequestTimedOut(OutboundRequestId, PeerId, Request<Ctx>),
InvalidValue(PeerId, Ctx::Height),
ValueProcessingError(PeerId, Ctx::Height),
}Variants
SendStatusUpdate
Periodical event triggering the broadcast of a status update
Status(Status<Ctx>)
A status update has been received from a peer
StartedHeight(Ctx::Height, HeightStartType)
Consensus just started a new height. The boolean indicates whether this was a restart or a new start.
Decided(Ctx::Height)
Consensus just decided on a new value
ValueRequest(InboundRequestId, PeerId, ValueRequest<Ctx>)
A ValueSync request has been received from a peer
ValueResponse(OutboundRequestId, PeerId, Option<ValueResponse<Ctx>>)
A (possibly empty or invalid) ValueSync response has been received
GotDecidedValues(InboundRequestId, RangeInclusive<Ctx::Height>, Vec<RawDecidedValue<Ctx>>)
Got a response from the application to our GetDecidedValues request
SyncRequestTimedOut(OutboundRequestId, PeerId, Request<Ctx>)
A request for a value timed out
InvalidValue(PeerId, Ctx::Height)
We received an invalid value (either certificate or value)
ValueProcessingError(PeerId, Ctx::Height)
An error occurred while processing a value