pub struct Status<Ctx: Context> {
pub peer_id: PeerId,
pub tip_height: Ctx::Height,
pub history_min_height: Ctx::Height,
}Fields
peer_id: PeerIdtip_height: Ctx::Heighthistory_min_height: Ctx::HeightTrait Implementations
Sourceimpl<Ctx: Context> BorshDeserialize for Status<Ctx>where
Ctx::Height: BorshDeserialize,
impl<Ctx: Context> BorshDeserialize for Status<Ctx>where
Ctx::Height: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl<Ctx: Context> BorshSerialize for Status<Ctx>where
Ctx::Height: BorshSerialize,
impl<Ctx: Context> BorshSerialize for Status<Ctx>where
Ctx::Height: BorshSerialize,
impl<Ctx: Context> Eq for Status<Ctx>